@@ -45,6 +45,10 @@ class CLI(cl1.CLI):
 				"    --key /path/to/key/private_key":"Specify the path to the private key.",
 				"    for smart cards:":"",
 				"    --smart-cards":"Enable the smart cards boolean.",
+				"--generate":"Generate a ssh key.",
+				"    --path /keys/mykey/":"Specify the keys directory path.",
+				"    --passphrase Passphrase123":"Specify the keys passphrase.",
+				"    --comment 'My Key'":"Specify the keys comment.",
 				"-h / --help":"Show the documentation.",
 			},
 			options={},
@@ -60,11 +64,11 @@ class CLI(cl1.CLI):
 			print(self.documentation)
 
 		# check create ssh config.
-		if self.argument_present('--create-alias'):
+		elif self.argument_present('--create-alias'):
 			
 			# create an ssh alias for the key.
 			if not self.argument_present('--smart-card'):
-				response = config.create_alias(self, 
+				response = config.create_alias( 
 					# the servers name.
 					server=self.get_argument('--server'), 
 					# the username.
@@ -80,7 +84,7 @@ class CLI(cl1.CLI):
 
 			# create an ssh alias for a smart card.
 			else:
-				response = config.create_alias(self, 
+				response = config.create_alias( 
 					# the servers name.
 					server=self.get_argument('--server'), 
 					# the username.
@@ -98,6 +102,16 @@ class CLI(cl1.CLI):
 			if response["error"] != None: print(response["error"])
 			else: print(response["message"])
 
+		# check create ssh config.
+		elif self.argument_present('--generate'):
+			
+			# generate a key.
+			response = key.generate(
+				directory=self.get_argument("--path"), 
+				passphrase=self.get_argument("--passphrase").replace("\\", ""), 
+				comment=self.get_argument("--comment"),)
+			r3sponse.log(response=response)
+
 		# invalid.
 		else: 
 			print(self.documentation)
